% Fundao Dam study - econometric analysis

% Import data and data transformations

clear all; clc; %#ok<CLALL>
DATA = load('brazil_data_main_3.mat');

% drop all incomplete surveys
filter = DATA.FIELD_STATUS == 10;
fields = fieldnames(DATA);
for i = 1:numel(fields)
    tmp = DATA.(fields{i});
    DATA.(fields{i}) = tmp(filter,:);
end
clear fields tmp filter i

% drop pilot observations:
filter = DATA.FASE == 8; % main 1
fields = fieldnames(DATA);
for i = 1:numel(fields)
    tmp = DATA.(fields{i});
    DATA.(fields{i}) = tmp(filter,:);
end
clear fields tmp filter i

DATA.bid = DATA.Q27_BID_INSTALMENT;

DATA.S12(isnan(DATA.S12)) = 0; % recode missing education to 0 - this is used as a categorical variable later anyway

DATA.wealth = DATA.PONTOS;

% Creating continous income variable using mid-points of selected income intervals:
DATA.income = NaN(size(DATA.SbjNum));
DATA.income(DATA.Q26 == 1) = 1000; %	1	Up to $ 1,000
DATA.income(DATA.Q26 == 2) = 1500; %2	More than R $ 1,000 to R $ 1,500
DATA.income(DATA.Q26 == 3) = 1750; %3	More than R $ 1,500 to R $ 2,000
DATA.income(DATA.Q26 == 4) = 2500; %4	More than R $ 2,000 to R $ 3,000
DATA.income(DATA.Q26 == 5) = 3500; %5	More than R $ 3,000 to R $ 4,000
DATA.income(DATA.Q26 == 6) = 4500; %6	More than R $ 4,000 to R $ 5,000
DATA.income(DATA.Q26 == 7) = 6500; %7	More than R $ 5,000 to R $ 8,000
DATA.income(DATA.Q26 == 8) = 9000; %8	More than R $ 8,000 to R $ 10,000
DATA.income(DATA.Q26 == 9) = 12500; %9	More than R $ 10,000 to R $ 15,000
DATA.income(DATA.Q26 == 10) = 15000; %10	More than R $ 15,000

% Income imputation (this is used for generating weights only)
DATA.Intercept(isnan(DATA.Intercept))=0;
DATA.Q26n = DATA.Q26; 
DATA.Q26n(DATA.Q26n>10) = NaN; % Replace response 11 and 12 with missing value
tbl = table(DATA.income,DATA.S3, ... % DATA.ORDEM_APLICACAO, 
    DATA.S5, DATA.S6, ...
    DATA.S6A, DATA.S8==2, DATA.S9, ...
    DATA.wealth, log(DATA.wealth), DATA.S11,DATA.S12,DATA.Intercept, ...
    'VariableNames',{'Income','City', ... % 'Response order',
        'Work_status','HH_size', ...
        'HH_children','Female','Age', ...
        'HH_wealth','log_HH_wealth', 'HH_head','Education','Intercept'});
tbl.City = categorical(tbl.City);
tbl.Work_status = categorical(tbl.Work_status);
tbl.HH_size = categorical(tbl.HH_size);
tbl.HH_children = categorical(tbl.HH_children);
tbl.HH_head = categorical(tbl.HH_head);
tbl.Education = categorical(tbl.Education);
lm = fitlm(tbl,'Income~City+Work_status+HH_size+HH_children+Female+Age+HH_wealth+log_HH_wealth+HH_head+Education+Intercept');

tbl2 = tbl(isnan(tbl.Income),:);
prediction = predict(lm,tbl2);
DATA.income_imputed = DATA.income;
DATA.income_imputed(isnan(DATA.income)) = prediction;


% % table_out is used to export data for Appendix 1
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% [~,SE,coef] = hac(lm,'type','HC','weights','HC1','display','off'); % get robust robust s.e.
% table_out(:,3) = num2cell(SE); % substituting for robust s.e.
% table_out(:,4) = num2cell(cell2mat(table_out(:,2))./cell2mat(table_out(:,3)));
% table_out(:,5) = num2cell(pv(cell2mat(table_out(:,2)),cell2mat(table_out(:,3))));
% 
% table_out(2:60,6) = {[0,1]};
% table_out(61:63,6) = lm.VariableInfo{lm.PredictorNames(6:8),2};
% table_out(64:end,6) = {[0,1]};
% table_out(2,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='2')};
% table_out(3,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='3')};
% table_out(4,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='4')};
% table_out(5,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='5')};
% table_out(6,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='6')};
% table_out(7,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='7')};
% table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='8')};
% table_out(9,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='9')};
% table_out(10,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='10')};
% table_out(11,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='11')};
% table_out(12,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='12')};
% table_out(13,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='13')};
% table_out(14,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='14')};
% table_out(15,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='15')};
% table_out(16,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='16')};
% table_out(17,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='17')};
% table_out(18,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='18')};
% table_out(19,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='19')};
% table_out(20,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='20')};
% table_out(21,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='21')};
% table_out(22,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='22')};
% table_out(23,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='23')};
% table_out(24,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='24')};
% table_out(25,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='25')};
% table_out(26,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='26')};
% table_out(27,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='27')};
% table_out(28,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='28')};
% table_out(29,7) = {nanmean(lm.Variables{:,lm.PredictorNames(1)}=='99')};
% table_out(30,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='3')};
% table_out(31,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='4')};
% table_out(32,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='5')};
% table_out(33,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='6')};
% table_out(34,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='7')};
% table_out(35,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='8')};
% table_out(36,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='9')};
% table_out(37,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='10')};
% table_out(38,7) = {nanmean(lm.Variables{:,lm.PredictorNames(2)}=='11')};
% table_out(39,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='2')}; % HH size
% table_out(40,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='3')};
% table_out(41,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='4')};
% table_out(42,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='5')};
% table_out(43,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='6')};
% table_out(44,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='7')};
% table_out(45,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='8')};
% table_out(46,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='9')};
% table_out(47,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='10')};
% table_out(48,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='11')};
% table_out(49,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='12')};
% table_out(50,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='13')};
% table_out(51,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='17')};
% table_out(52,7) = {nanmean(lm.Variables{:,lm.PredictorNames(3)}=='32')};
% table_out(53,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='1')}; % HH children
% table_out(54,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='2')};
% table_out(55,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='3')};
% table_out(56,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='4')};
% table_out(57,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='5')};
% table_out(58,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='6')};
% table_out(59,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='7')};
% table_out(60,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}==true)}; % female
% table_out(61:63,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(6:8)})');
% table_out(64,7) = {nanmean(lm.Variables{:,lm.PredictorNames(9)}=='1')}; % HH head
% table_out(65,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='2')}; % education
% table_out(66,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='3')}; % education
% table_out(67,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='4')}; 
% table_out(68,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='5')}; 
% table_out(69,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='6')}; 
% table_out(70,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='7')}; 
% table_out(71,7) = {nanmean(lm.Variables{:,lm.PredictorNames(11)}==true)}; 
% table_out(end+1,1) = {'R2 (adj)'};
% table_out(end,2) = num2cell(lm.Rsquared.Adjusted);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);


clear lm prediction tbl tbl2 table_out SE coef

% Missing income treatment
DATA.income_filled = DATA.income;
DATA.income_filled(isnan(DATA.income_filled)) = nanmean(DATA.income_filled);
DATA.income_missing = isnan(DATA.income);

% [dstats(DATA.income_filled), dstats(DATA.income_filled.*(DATA.Weight_Imputed))]
% [dstats(DATA.income), dstats(DATA.income.*(DATA.WEIGHT))]

% dstats(DATA.Weight_Imputed)
% dstats(DATA.WEIGHT)

% Defining protest responses
DATA.protest = ((DATA.Q28 == 4) | (DATA.Q28 == 5) | (DATA.Q28 == 6) | (DATA.Q28 == 7) | (DATA.Q28 == 12) | (DATA.Q28 == 13));

% Distances:
dist_table = [1,487.500000000000,487.500000000000;2,493.400000000000,493.400000000000;3,462.200000000000,462.200000000000;4,493,493;5,486,486;6,494.400000000000,494.400000000000;7,485.200000000000,485.200000000000;15,284.100000000000,284.100000000000;16,265.700000000000,265.700000000000;17,266.500000000000,266.500000000000;18,284.800000000000,284.800000000000;19,274.400000000000,262.800000000000;8,76.7000000000000,76.7000000000000;9,92,92;10,86.4000000000000,86.4000000000000;11,96.9000000000000,96.9000000000000;12,1647.30000000000,1374.20000000000;13,1634,1361;14,1655,1381;22,823.900000000000,823.900000000000;23,821.600000000000,821.600000000000;24,744.800000000000,744.800000000000;25,734.400000000000,734.400000000000;20,2176,2065;21,2184,2073;26,133.900000000000,0;27,369,0;28,0,0];
DATA.distance_marianna = vlookup(DATA.S3,dist_table(:,1),dist_table(:,2));
DATA.distance_doce = vlookup(DATA.S3,dist_table(:,1),dist_table(:,3));
clear dist_table

%% non-parametric analysis


bids = unique(DATA.bid);

% Frequency table with weighting:
Frequency_table_W = zeros(length(bids),6);
Frequency_table_W(:,1) = bids;
for i = 1:length(bids)
    Frequency_table_W(i,2) = sum(DATA.Weight_Imputed(DATA.bid == bids(i)).*(DATA.Q27(DATA.bid == bids(i)) == 2)); % no of people who voted no (weighted)
    Frequency_table_W(i,3) = sum(DATA.Weight_Imputed(DATA.bid == bids(i)).*(DATA.Q27(DATA.bid == bids(i)) == 1)); % no of people who voted yes (weighted)
    Frequency_table_W(i,4) = sum(DATA.Weight_Imputed(DATA.bid == bids(i))); % no of people total (weighted)
end
Frequency_table_W(:,5) = Frequency_table_W(:,2)./Frequency_table_W(:,4);  % NO answers
Frequency_table_W(:,6) = Frequency_table_W(:,3)./Frequency_table_W(:,4);

% Frequency table without weighting
Frequency_table = zeros(length(bids),6);
Frequency_table(:,1) = bids;
for i = 1:length(bids)
    Frequency_table(i,2) = sum(DATA.Q27(DATA.bid == bids(i)) == 2); % no of people who voted no (weighted)
    Frequency_table(i,3) = sum(DATA.Q27(DATA.bid == bids(i)) == 1); % no of people who voted yes (weighted)
    Frequency_table(i,4) = sum(DATA.bid == bids(i)); % no of people total (weighted)
end
Frequency_table(:,5) = Frequency_table(:,2)./Frequency_table(:,4);  % NO answers
Frequency_table(:,6) = Frequency_table(:,3)./Frequency_table(:,4);

% Scaling, so that the total number of individuals would not change
Frequency_table_W(:,2:4) = Frequency_table_W(:,2:4).*(Frequency_table(:,4)./Frequency_table_W(:,4)); 

% Lewbel_Watanabe WTP (weigted):
WTP = sum((Frequency_table_W(:,1)-[0;Frequency_table_W(1:end-1,1)]).*Frequency_table_W(:,3)./Frequency_table_W(:,4)); % mean WTP
SD = sqrt(sum(Frequency_table_W(:,5).*(1-Frequency_table_W(:,5))./Frequency_table_W(:,4).*((Frequency_table_W(:,1)-[0;Frequency_table_W(1:end-1,1)])).^2)); %. s.e. (based on Haab McConnell) 

% plot LW CDF
figure(1)
SEA = sqrt(Frequency_table_W(:,2).*Frequency_table_W(:,3)./(Frequency_table_W(:,4).^3)); % standard errors based on ML Hessian
xx = linspace(0,200,500);
hold on;
KMplot(1) = stairs([0;Frequency_table_W(:,1)],[0;Frequency_table_W(:,5)],'b-'); % Taking NO answers
KMplot(2) = stairs([0;Frequency_table_W(:,1)],[0;Frequency_table_W(:,5)+norminv(0.025)*SEA],'r--');
KMplot(3) = stairs([0;Frequency_table_W(:,1)],[0;Frequency_table_W(:,5)+norminv(0.975)*SEA],'r--');
set(KMplot(1),'linewidth',2);
hold off
xlabel('WTP'); ylabel('Probability'); title('Empirical CDF')
set(gca, 'YGrid', 'on', 'GridLineStyle', ':')
ylim([0,1])
set(gca,'XTick', Frequency_table_W(:,1))
set(gca,'Position',[.13 .11 .85 .82]);
set(gcf,'Color', 'w')
legend([KMplot(1),KMplot(2)],'Lewbel-Watanabe (lower bound) estimator','95% confidence interval','Location', 'southeast')

saveas(gcf,'LW CDF','png')

clear xx WTPA SEA  bids KMplot 

Results_nonparametric = {'WTP (mean)','WTP (s.e.)'};
Results_nonparametric(2,:) = num2cell([WTP,SD])

clear WTP SD i 


%% parametric analysis:


% create lower and upper bound for each respondent
DATA.bounds = [DATA.bid.*(DATA.Q27==1),DATA.bid.*(DATA.Q27==2)];
DATA.bounds(DATA.bounds(:,1)==0,1) = 0; % lower bound = 0
DATA.bounds(DATA.bounds(:,2)==0,2) = DATA.income_filled(DATA.bounds(:,2)==0); % assuming upper bound = respondents' income
INPUT.bounds = DATA.bounds;
INPUT.WT = DATA.Weight_Imputed;

% % fit parametric distributions to data:
% INPUT.Spike = 0; % no zero inflation
% load('Results_parametric0');
% INPUT.Results = Results_parametric0;
% % INPUT.Results = [];
% [Results_parametric0, Results_parametric_summary0] = FitParametricDistributions(INPUT);
% save('Results_parametric0.mat','Results_parametric0')
% save('Results_parametric_summary0.mat','Results_parametric_summary0')
% 
% INPUT.Spike = 1; % with zero inflation
% load('Results_parametric1');
% INPUT.Results = Results_parametric1;
% % INPUT.Results = [];
% [Results_parametric1, Results_parametric_summary1] = FitParametricDistributions(INPUT);
% save('Results_parametric1.mat','Results_parametric1')
% save('Results_parametric_summary1.mat','Results_parametric_summary1')

% % retain the best starting values from two sets of estimats:
% R1 = load('Results_parametric0.mat');
% R2 = load('Results_parametric00sqp.mat');
%     for i=1:length(R1.Results_parametric0.Distributions)
%         if ((R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).fval < R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).fval) && (R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).RealMin == 0)) || ...
%                 ((R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).RealMin == 0) && (R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).RealMin == 1))                
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).fval - R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).fval
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).beta = R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).beta;
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).fval = R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).fval;
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).RealMin = R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).RealMin;
%         end
%     end  
% save('Results_parametric0.mat','-struct','R1') %- this is my newest results file
%   
% R1 = load('Results_parametric1.mat');
% R2 = load('Results_parametric10sqp.mat');
%     for i=1:length(R1.Results_parametric1.Distributions)
%         if ((R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).fval < R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).fval) && (R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).RealMin == 0)) || ...
%                 ((R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).RealMin == 0) && (R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).RealMin == 1))                
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).fval - R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).fval
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).beta = R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).beta;
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).fval = R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).fval;
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).RealMin = R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).RealMin;
%         end
%     end    
% save('Results_parametric1','-struct','R1') %- this is my newest results file


% compile the results of the parametric analysis:
load('Results_parametric0');
load('Results_parametric1');
load('Results_parametric_summary0');
load('Results_parametric_summary1');
Results_parametric(1:size(Results_parametric0.Distributions,1)+size(Results_parametric1.Distributions,1),1) = [Results_parametric0.Distributions(:,2);Results_parametric1.Distributions(:,2)];
Results_parametric_summary0 = [Results_parametric_summary0(:,1),zeros(size(Results_parametric_summary0(:,1))),Results_parametric_summary0(:,2:end)];
Results_parametric_summary1 = [Results_parametric_summary1(:,1),ones(size(Results_parametric_summary1(:,1))),Results_parametric_summary1(:,2:end)];
Results_parametric(1:size(Results_parametric0.Distributions,1),2:size(Results_parametric_summary0,2)+1) = num2cell(Results_parametric_summary0);
Results_parametric(size(Results_parametric1.Distributions,1)+1:end,2:size(Results_parametric_summary1,2)+1) = num2cell(Results_parametric_summary1);
% drop distributions that did not converge:
for i = 1:size(Results_parametric,1)
    idx(i,1) = (Results_parametric{i,end-1} > 100) | (Results_parametric{i,end-1} == 0) | isnan(Results_parametric{i,end-1}) | isinf(Results_parametric{i,end-1}) | ~isreal(Results_parametric{i,end-1}) | ...
    (Results_parametric{i,end-2} > 500) | (Results_parametric{i,end-2} == 0) | isnan(Results_parametric{i,end-2}) | isinf(Results_parametric{i,end-2}) | ~isreal(Results_parametric{i,end-2});
end
Results_parametric(idx==1,:) = [];
Results_parametric = sortrows(Results_parametric,[5,4]);
Results_parametric = [{'Distribution','Log-likelihood','Zero inflation','AIC/n','BIC/n','n - observations','k - parameters','WTP (mean)','WTP (s.e.)','RealMin'};Results_parametric];

Results_parametric

% plot step-curve with CDF of the best fitting parametric dist.
figure(2)
SEA = sqrt(Frequency_table_W(:,2).*Frequency_table_W(:,3)./(Frequency_table_W(:,4).^3)); % standard errors based on ML Hessian
xx = linspace(0,max(DATA.bid),500);
Betas_param = Results_parametric1.Exponential.beta';
pSpike = normcdf(Betas_param(2)); % p1
wblF = pSpike + (1-pSpike).*cdf('Exponential',xx,Betas_param(1));
sim1 = 1e5;
Betas_param_sim = mvnrnd(Betas_param,Results_parametric1.Exponential.ihess,sim1)';
wblF_sim = zeros(sim1,500);
parfor i = 1:sim1
    pSpike = normcdf(Betas_param_sim(2,i)); % p1
    wblF_sim(i,:) = pSpike + (1-pSpike).*cdf('Exponential',xx,Betas_param_sim(1,i));    
end
wblF_sim_l = quantile(wblF_sim,0.025);
wblF_sim_u = quantile(wblF_sim,0.975);
hold on;
KMplot(1) = stairs([0;Frequency_table_W(:,1)],[0;Frequency_table_W(:,5)],'b-'); % Taking NO answers
KMplot(2) = stairs([0;Frequency_table_W(:,1)],[0;Frequency_table_W(:,5)+norminv(0.025)*SEA],'b--');
KMplot(3) = stairs([0;Frequency_table_W(:,1)],[0;Frequency_table_W(:,5)+norminv(0.975)*SEA],'b--');
DISTplot(1) = plot(xx,wblF,'r-');
DISTplot(2) = plot(xx,wblF_sim_l,'r--');
DISTplot(3) = plot(xx,wblF_sim_u,'r--');
set(KMplot(1),'linewidth',2);
set(DISTplot(1),'linewidth',2);
hold off
xlabel('WTP [BRL]'); ylabel('Probability'); title('Empirical CDF')
set(gca, 'YGrid', 'on', 'GridLineStyle', ':')
ylim([0,1])
set(gca,'XTick', Frequency_table_W(:,1))
set(gca,'Position',[.07 .11 .92 .82]);
set(gcf,'Color', 'w')
legend([KMplot(1),KMplot(2), DISTplot(1),DISTplot(2)],'Lewbel-Watanabe (lower bound)','95% confidence interval','Fitted parametric distribution','95% confidence interval', 'Location', 'southeast')
saveas(gcf,'LW + param CDF','png')

clear Distributions i idx INPUT Results_summary_0 Results_summary_1 
clear Betas_param Betas_param_sim DISTplot freq_tableA i idx INPUT KMplot Results_parametric0 Results_parametric1 Results_parametric_summary0 Results_parametric_summary1 pSpike
clear SEA sim1 wblF wblF_sim wblF_sim_l wblF_sim_u xx WTPA 


%% validity - monotonicity


% plot LW CDF (unweighted)
figure(3)
SEA = sqrt(Frequency_table(:,2).*Frequency_table(:,3)./(Frequency_table(:,4).^3)); % standard errors based on ML Hessian
xx = linspace(0,200,500);
hold on;
KMplot(1) = stairs([0;Frequency_table(:,1)],[0;Frequency_table(:,5)],'b-'); % Taking NO answers
KMplot(2) = stairs([0;Frequency_table(:,1)],[0;Frequency_table(:,5)+norminv(0.025)*SEA],'r--');
KMplot(3) = stairs([0;Frequency_table(:,1)],[0;Frequency_table(:,5)+norminv(0.975)*SEA],'r--');
set(KMplot(1),'linewidth',2);
hold off
xlabel('WTP'); ylabel('Probability'); title('Empirical CDF')
set(gca, 'YGrid', 'on', 'GridLineStyle', ':')
ylim([0,1])
set(gca,'XTick', Frequency_table(:,1))
set(gca,'Position',[.13 .11 .85 .82]);
set(gcf,'Color', 'w')
legend([KMplot(1),KMplot(2)],'Lewbel-Watanabe (lower bound) estimator','95% confidence interval','Location', 'southeast')
saveas(gcf,'LW CDF uw','png')

% Lewbel_Watanabe WTP (weigted):
WTP = sum((Frequency_table(:,1)-[0;Frequency_table(1:end-1,1)]).*Frequency_table(:,3)./Frequency_table(:,4)); % mean WTP
SD = sqrt(sum(Frequency_table(:,5).*(1-Frequency_table(:,5))./Frequency_table(:,4).*((Frequency_table(:,1)-[0;Frequency_table(1:end-1,1)])).^2)); %. s.e. (based on Haab McConnell) 

Results_nonparametric_uw = {'WTP (mean)','WTP (s.e.)'};
Results_nonparametric_uw(2,:) = num2cell([WTP,SD])


clear xx WTPA SEA bids KMplot 


%% regressions - explanatory variables of 'no' votes


DATA.Q11c = DATA.Q11;
DATA.Q11c(DATA.Q11c > 5) = NaN;
DATA.Q13c = DATA.Q13;
DATA.Q13c(DATA.Q13c > 5) = NaN;
DATA.D1c = DATA.D1;
DATA.D1c(DATA.D1c > 5) = NaN;
DATA.D1cf = DATA.D1c;
DATA.D1cf_missing = isnan(DATA.D1cf);
DATA.D1cf(DATA.D1cf_missing) = nanmean(DATA.D1cf);
DATA.D2c = DATA.D2;
DATA.D2c(DATA.D2c > 5) = NaN;
DATA.D2cf = DATA.D2c;
DATA.D2cf_missing = isnan(DATA.D2cf);
DATA.D2cf(DATA.D2cf_missing) = nanmean(DATA.D2cf);
DATA.D3c = DATA.D3;
DATA.D3c(DATA.D3c > 5) = NaN;
DATA.D3cf = DATA.D3c;
DATA.D3cf_missing = isnan(DATA.D3cf);
DATA.D3cf(DATA.D3cf_missing) = nanmean(DATA.D3cf);
DATA.D4c = DATA.D4;
DATA.D4c(DATA.D4c > 5) = NaN;
DATA.D4cf = DATA.D4c;
DATA.D4cf_missing = isnan(DATA.D4cf);
DATA.D4cf(DATA.D4cf_missing) = nanmean(DATA.D4cf);
DATA.D5c = DATA.D5;
DATA.D5c(DATA.D5c > 5) = NaN;
DATA.D5cf = DATA.D5c;
DATA.D5cf_missing = isnan(DATA.D5cf);
DATA.D5cf(DATA.D5cf_missing) = nanmean(DATA.D5cf);
DATA.D6c = DATA.D6;
DATA.D6c(DATA.D6c > 5) = NaN;
DATA.D6cf = DATA.D6c;
DATA.D6cf_missing = isnan(DATA.D6cf);
DATA.D6cf(DATA.D6cf_missing) = nanmean(DATA.D6cf);
DATA.D7c = DATA.D7;
DATA.D7c(DATA.D7c > 5) = NaN;
DATA.D7cf = DATA.D7c;
DATA.D7cf_missing = isnan(DATA.D7cf);
DATA.D7cf(DATA.D7cf_missing) = nanmean(DATA.D7cf);
DATA.D8c = DATA.D8;
DATA.D8c(DATA.D8c > 5) = NaN;
DATA.D8cf = DATA.D8c;
DATA.D8cf_missing = isnan(DATA.D8cf);
DATA.D8cf(DATA.D8cf_missing) = nanmean(DATA.D8cf);
DATA.D9c = DATA.D9;
DATA.D9c(DATA.D9c > 3) = NaN;
DATA.D9c(DATA.D9c==2) = -1;
DATA.D9c(DATA.D9c==1) = 0;
DATA.D9c(DATA.D9c==3) = 1;
DATA.D9cf = DATA.D9c;
DATA.D9cf_missing = isnan(DATA.D9cf);
DATA.D9cf(DATA.D9cf_missing) = nanmean(DATA.D9cf);
DATA.D10c = DATA.D10;
DATA.D10c(DATA.D10c > 4) = NaN;
DATA.D10cf = DATA.D10c;
DATA.D10cf_missing = isnan(DATA.D10cf);
DATA.D10cf(DATA.D10cf_missing) = nanmean(DATA.D10cf);
DATA.D13(DATA.D13==9) = 8; % pressure to vote: [DO NOT READ] Do not know / difficult to say = [DO NOT READ] Refuse to answer
DATA.D13c = DATA.D13;
DATA.D13c(DATA.D13c > 7) = NaN;
DATA.D13c(DATA.D13c==7) = -1;
DATA.D13c(DATA.D13c==5) = 0;
DATA.D13c(DATA.D13c==6) = 1;
% Pause questions: % Q2, Q3, Q4, Q6, Q7, Q8, Q9, Q10, Q14, Q15, Q16A, Q16B, Q17, Q18, Q19, Q20, Q22
DATA.pause_incorrect = ...
sum([~isnan(DATA.Q2),~isnan(DATA.Q3),~isnan(DATA.Q4),~isnan(DATA.Q6),~isnan(DATA.Q7),~isnan(DATA.Q8),~isnan(DATA.Q9),~isnan(DATA.Q10),...
    ~isnan(DATA.Q14),~isnan(DATA.Q15),~isnan(DATA.Q16A),~isnan(DATA.Q16B),~isnan(DATA.Q17),~isnan(DATA.Q18),~isnan(DATA.Q19),~isnan(DATA.Q20),~isnan(DATA.Q22)],2) - ...
sum([DATA.Q2==1,DATA.Q3==1,DATA.Q4==1,DATA.Q6==1,DATA.Q7==1,DATA.Q8==1,DATA.Q9==1,DATA.Q10==1,...
    DATA.Q14==1,DATA.Q15==1,DATA.Q16A==1,DATA.Q16B==1,DATA.Q17==1,DATA.Q18==1,DATA.Q19==1,DATA.Q20==1,DATA.Q22==1],2);
% dstats(DATA.pause_incorrect,1)
DATA.Intercept(isnan(DATA.Intercept))=0;

DATA.Q26n = DATA.Q26; 
DATA.Q26n(DATA.Q26n>10) = NaN; % Replace response 11 and 12 with missing value

tbl = table(DATA.Q27==2,DATA.Q27==1,DATA.bid,DATA.bid,log(DATA.bid),DATA.Q28,DATA.protest,...
    DATA.income,log(DATA.income),DATA.income_filled,log(DATA.income_filled),DATA.income_missing,DATA.Q26,DATA.Q26n,...
    DATA.REGION, DATA.S2C, DATA.S3, ... % DATA.ORDEM_APLICACAO, 
    DATA.S5, DATA.S6, DATA.S6, DATA.S6A, DATA.S7,...
    DATA.S8==2, DATA.S9,log(DATA.S9),(DATA.S9/10).^2, DATA.S9_FX, DATA.wealth, log(DATA.wealth), DATA.S11, DATA.S12,...
    DATA.Q1,DATA.Q1<4,...
    DATA.Q2==1,DATA.Q3==1,DATA.Q4==1,DATA.Q6==1,...
    DATA.Q7==1,DATA.Q8==1,DATA.Q9==1,DATA.Q10==1,...
    DATA.Q11,DATA.Q11c,DATA.Q13,DATA.Q13c,...    
    DATA.Q14==1,DATA.Q15==1,DATA.Q16A==1,DATA.Q16B==1,DATA.Q17==1,...
    DATA.Q18==1,DATA.Q19==1,DATA.Q20==1,DATA.Q22==1,...
    DATA.pause_incorrect,DATA.pause_incorrect>0,...
    DATA.D1, DATA.D2, DATA.D3, DATA.D4, DATA.D5, DATA.D6,...
    DATA.D1c, DATA.D2c, DATA.D3c, DATA.D4c, DATA.D5c, DATA.D6c,...    
    DATA.D1cf, DATA.D2cf, DATA.D3cf, DATA.D4cf, DATA.D5cf, DATA.D6cf,...
    DATA.D1cf_missing, DATA.D2cf_missing, DATA.D3cf_missing, DATA.D4cf_missing, DATA.D5cf_missing, DATA.D6cf_missing,...    
    DATA.D7,DATA.D8,DATA.D9,DATA.D10,...
    DATA.D7c,DATA.D8c,DATA.D9c,DATA.D10c,...
    DATA.D7cf,DATA.D8cf,DATA.D9cf,DATA.D10cf,...
    DATA.D7cf_missing,DATA.D8cf_missing,DATA.D9cf_missing,DATA.D10cf_missing,...
    DATA.D13,DATA.D13c,DATA.D14,...
    DATA.D17, DATA.D18, DATA.D20, ...
    DATA.D17, DATA.D18, DATA.D20, ...
    DATA.Intercept,DATA.Srvyr, ...
    DATA.Weight_Imputed, ...
    DATA.distance_marianna, DATA.distance_doce,...
    'VariableNames',{'Vote_No','Vote_Yes','Bid','Bid_c','Log_Bid','Reasons_to_vote_no','Protest_no',...
        'Income','Log_Income','Income_filled','Log_Income_filled','Income_missing','Income_bracket','Income_bracket_num',...
        'Region','State_born', 'City', ... % 'Response order',
        'Work_status','HH_size','HH_size_c','HH_children','HH_income',...
        'Female','Age','log_Age','Age_2','Age_category','HH_wealth','log_HH_wealth','HH_head','Education',...
        'Visited_Mariana','Visited_Mariana_yes',...
        'Understand_paid','Understand_water','Understand_connection','Understand_actions',...
        'Understand_fish','Understand_forest','Understand_water_species','Understand_birds',...
        'Environmental_damage_serious','Environmental_damage_serious_c','Cultural_damage_serious','Cultural_damage_serious_c',...        
        'Understand_decreasing_damage','Understand_safety','Understand_dam_risk','Understand_env_risk','Understand_dry_tailing',...
        'Understand_dry_dams','Understand_obstacles','Understand_split_expenses','Understand_money_monitored',...
        'Incorrect_pause_q','Incorrect_pause_q_1',...
        'Concerned_environment','Trust_damage_assessment','Believe_recovery_time','Believe_DT_solution','Believe_DT_time','Believe_DT_vote',...
        'Concerned_environment_c','Trust_damage_assessment_c','Believe_recovery_time_c','Believe_DT_solution_c','Believe_DT_time_c','Believe_DT_vote_c',...
        'Concerned_environment_cf','Trust_damage_assessment_cf','Believe_recovery_time_cf','Believe_DT_solution_cf','Believe_DT_time_cf','Believe_DT_vote_cf',...
        'Concerned_environment_cf_missing','Trust_damage_assessment_cf_missing','Believe_recovery_time_cf_missing','Believe_DT_solution_cf_missing','Believe_DT_time_cf_missing','Believe_DT_vote_cf_missing',...
        'Believe_tax_rise','Believe_DT_companies','Believe_tax_amount','Payment_difficult',...
        'Believe_tax_rise_c','Believe_DT_companies_c','Believe_tax_amount_c','Payment_difficult_c',...
        'Believe_tax_rise_cf','Believe_DT_companies_cf','Believe_tax_amount_cf','Payment_difficult_cf',...
        'Believe_tax_rise_cf_missing','Believe_DT_companies_cf_missing','Believe_tax_amount_cf_missing','Payment_difficult_cf_missing',...
        'Pressure_to_vote','Pressure_to_vote_c','Receive_electricity_bill',...
        'Involevent','Understanding','Sit_stand',...
        'Involevent_c','Understanding_c','Sit_stand_c',...
        'Intercept','Interviewer',...
        'Weights',...
        'Distance_Marianna','Distance_Doce'});
    
tbl.Vote_No = double(tbl.Vote_No);
tbl.Vote_Yes = double(tbl.Vote_Yes);
tbl.Bid = categorical(tbl.Bid);
tbl.Reasons_to_vote_no = categorical(tbl.Reasons_to_vote_no);
tbl.Income_bracket = categorical(tbl.Income_bracket);
tbl.Region = categorical(tbl.Region);
% tbl.ORDEM_APLICACAO = categorical(tbl.ORDEM_APLICACAO);
tbl.State_born = categorical(tbl.State_born);
tbl.City = categorical(tbl.City);
tbl.Age_category = categorical(tbl.Age_category);
tbl.Work_status = categorical(tbl.Work_status);
tbl.HH_size = categorical(tbl.HH_size);
tbl.HH_children = categorical(tbl.HH_children);
tbl.HH_income = categorical(tbl.HH_income);
tbl.HH_head = categorical(tbl.HH_head);
tbl.Education = categorical(tbl.Education);
tbl.Visited_Mariana = categorical(tbl.Visited_Mariana);
tbl.Environmental_damage_serious = categorical(tbl.Environmental_damage_serious);
tbl.Cultural_damage_serious = categorical(tbl.Cultural_damage_serious);
tbl.Concerned_environment = categorical(tbl.Concerned_environment);
tbl.Trust_damage_assessment = categorical(tbl.Trust_damage_assessment);
tbl.Believe_recovery_time = categorical(tbl.Believe_recovery_time);
tbl.Believe_DT_solution = categorical(tbl.Believe_DT_solution);
tbl.Believe_DT_time = categorical(tbl.Believe_DT_time);
tbl.Believe_DT_vote = categorical(tbl.Believe_DT_vote);
tbl.Believe_tax_rise = categorical(tbl.Believe_tax_rise);
tbl.Believe_DT_companies = categorical(tbl.Believe_DT_companies);
tbl.Believe_tax_amount = categorical(tbl.Believe_tax_amount);
tbl.Payment_difficult = categorical(tbl.Payment_difficult);
tbl.Pressure_to_vote = categorical(tbl.Pressure_to_vote);
tbl.Receive_electricity_bill = categorical(tbl.Receive_electricity_bill);
tbl.Involevent = categorical(tbl.Involevent);
tbl.Understanding = categorical(tbl.Understanding);
tbl.Sit_stand = categorical(tbl.Sit_stand);
tbl.Interviewer = categorical(tbl.Interviewer);

% bid + income - simple linear regression models
lm = fitlm(tbl,'Vote_No~Log_Bid') % bid only
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing') % bid + income
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing+log_HH_wealth+Age+Female+HH_size_c+Education+Work_status') % bid + income + socio-demographics + education + work status
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing+log_HH_wealth+Age+Female+HH_size_c+Region') % bid + income + socio-demographics + region fixed effects
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing+log_HH_wealth+Age+Female+HH_size_c+City') % bid + income + socio-demographics + city fixed effects
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing+Visited_Mariana_yes+Concerned_environment_cf+Concerned_environment_cf_missing+Trust_damage_assessment_cf+Trust_damage_assessment_cf_missing+Believe_recovery_time_cf+Believe_recovery_time_cf_missing+Believe_DT_solution_cf+Believe_DT_solution_cf_missing+Believe_DT_time_cf+Believe_DT_time_cf_missing+Believe_DT_vote_cf+Believe_DT_vote_cf_missing+Believe_tax_rise_cf+Believe_tax_rise_cf_missing+Believe_DT_companies_cf+Believe_DT_companies_cf_missing+Believe_tax_amount_cf+Believe_tax_amount_cf_missing+Payment_difficult_cf+Payment_difficult_cf_missing') % bid + income + debriefing
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing+Incorrect_pause_q+Pressure_to_vote+Involevent_c+Understanding_c+Sit_stand_c+Intercept+Interviewer') % bid + income + quality
lm = fitlm(tbl,'Vote_No~Log_Bid+Distance_Marianna') % bid only
lm = fitlm(tbl,'Vote_No~Log_Bid+Distance_Doce') % bid only



% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% [~,SE,coef] = hac(lm,'type','HC','weights','HC1','display','off'); % robust s.e.
% table_out(:,3) = num2cell(SE); % substituting for robust s.e.
% table_out(:,4) = num2cell(cell2mat(table_out(:,2))./cell2mat(table_out(:,3)));
% table_out(:,5) = num2cell(pv(cell2mat(table_out(:,2)),cell2mat(table_out(:,3))));
% table_out(end+1,1) = {'R2 (adj)'};
% table_out(end,2) = num2cell(lm.Rsquared.Adjusted);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);

% bid + income - binary probit:
lm = fitglm([tbl.Log_Bid],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid only
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid , tbl. income
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.log_HH_wealth, tbl.Age, tbl.Female, tbl.HH_size_c, DummyVar(tbl.Education,1), DummyVar(tbl.Work_status,1)],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid , tbl. income , tbl. socio-demographics , tbl. education , tbl. work status
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.log_HH_wealth, tbl.Age, tbl.Female, tbl.HH_size_c, DummyVar(tbl.Region,1)],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid , tbl. income , tbl. socio-demographics , tbl. region fixed effects
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.log_HH_wealth, tbl.Age, tbl.Female, tbl.HH_size_c, DummyVar(tbl.City)],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid , tbl. income , tbl. socio-demographics , tbl. city fixed effects
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.Visited_Mariana_yes, tbl.Concerned_environment_cf, tbl.Concerned_environment_cf_missing, tbl.Trust_damage_assessment_cf, tbl.Trust_damage_assessment_cf_missing, tbl.Believe_recovery_time_cf, tbl.Believe_recovery_time_cf_missing, tbl.Believe_DT_solution_cf, tbl.Believe_DT_solution_cf_missing, tbl.Believe_DT_time_cf, tbl.Believe_DT_time_cf_missing, tbl.Believe_DT_vote_cf, tbl.Believe_DT_vote_cf_missing, tbl.Believe_tax_rise_cf, tbl.Believe_tax_rise_cf_missing, tbl.Believe_DT_companies_cf, tbl.Believe_DT_companies_cf_missing, tbl.Believe_tax_amount_cf, tbl.Believe_tax_amount_cf_missing, tbl.Payment_difficult_cf, tbl.Payment_difficult_cf_missing],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid , tbl. income , tbl. debriefing
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.Incorrect_pause_q, DummyVar(tbl.Pressure_to_vote,1), tbl.Involevent_c, tbl.Understanding_c, tbl.Sit_stand_c, tbl.Intercept, DummyVar(tbl.Interviewer,1)],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid , tbl. income , tbl. quality
lm = fitglm([tbl.Log_Bid, tbl.Distance_Marianna],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid only
lm = fitglm([tbl.Log_Bid, tbl.Distance_Doce],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid only

% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% table_out(end+1,1) = {'LL'};
% table_out(end,2) = num2cell(lm.LogLikelihood);
% table_out(end+1,1) = {'AIC/n'};
% table_out(end,2) = num2cell((2*lm.NumCoefficients-2*lm.LogLikelihood)./lm.NumObservations);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);


% debriefing questions - simple linear regression:
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing+Visited_Mariana_yes+Concerned_environment_cf+Trust_damage_assessment_cf+Believe_recovery_time_cf+Believe_DT_solution_cf+Believe_DT_time_cf+Believe_DT_vote_cf+Believe_tax_rise_cf+Believe_DT_companies_cf+Believe_tax_amount_cf+Payment_difficult_cf + Concerned_environment_cf_missing+Trust_damage_assessment_cf_missing+Believe_recovery_time_cf_missing+Believe_DT_solution_cf_missing+Believe_DT_time_cf_missing+Believe_DT_vote_cf_missing+Believe_tax_rise_cf_missing+Believe_DT_companies_cf_missing+Believe_tax_amount_cf_missing+Payment_difficult_cf_missing') % bid + income + debriefing

% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% [~,SE,coef] = hac(lm,'type','HC','weights','HC1','display','off'); % robust s.e.
% table_out(:,3) = num2cell(SE); % substituting for robust s.e.
% table_out(:,4) = num2cell(cell2mat(table_out(:,2))./cell2mat(table_out(:,3)));
% table_out(:,5) = num2cell(pv(cell2mat(table_out(:,2)),cell2mat(table_out(:,3))));
% table_out(2:25,6) = lm.VariableInfo{lm.PredictorNames,2};
% table_out(2:25,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames})');
% table_out(end+1,1) = {'R2 (adj)'};
% table_out(end,2) = num2cell(lm.Rsquared.Adjusted);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);

% debriefing questions - binary probit regression:
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.Visited_Mariana_yes, tbl.Concerned_environment_cf, tbl.Trust_damage_assessment_cf, tbl.Believe_recovery_time_cf, tbl.Believe_DT_solution_cf, tbl.Believe_DT_time_cf, tbl.Believe_DT_vote_cf, tbl.Believe_tax_rise_cf, tbl.Believe_DT_companies_cf, tbl.Believe_tax_amount_cf, tbl.Payment_difficult_cf , tbl. Concerned_environment_cf_missing, tbl.Trust_damage_assessment_cf_missing, tbl.Believe_recovery_time_cf_missing, tbl.Believe_DT_solution_cf_missing, tbl.Believe_DT_time_cf_missing, tbl.Believe_DT_vote_cf_missing, tbl.Believe_tax_rise_cf_missing, tbl.Believe_DT_companies_cf_missing, tbl.Believe_tax_amount_cf_missing, tbl.Payment_difficult_cf_missing],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid , tbl. income , tbl. debriefing

% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% table_out(2:25,6) = lm.VariableInfo{lm.PredictorNames,2};
% table_out(2:25,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames})');
% table_out(end+1,1) = {'LL'};
% table_out(end,2) = num2cell(lm.LogLikelihood);
% table_out(end+1,1) = {'AIC/n'};
% table_out(end,2) = num2cell((2*lm.NumCoefficients-2*lm.LogLikelihood)./lm.NumObservations);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);


% survey quality controls - simple linear regression:
lm = fitlm(tbl,'Vote_No~Log_Bid+Log_Income_filled+Income_missing+Incorrect_pause_q+Pressure_to_vote+Involevent_c+Understanding_c+Sit_stand_c+Intercept') % bid + income + quality

% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% [~,SE,coef] = hac(lm,'type','HC','weights','HC1','display','off'); % robust s.e.
% table_out(:,3) = num2cell(SE); % substituting for robust s.e.
% table_out(:,4) = num2cell(cell2mat(table_out(:,2))./cell2mat(table_out(:,3)));
% table_out(:,5) = num2cell(pv(cell2mat(table_out(:,2)),cell2mat(table_out(:,3))));
% table_out(2:size(lm.PredictorNames(1:3),1)+2,6) = lm.VariableInfo{lm.PredictorNames(1:4),2};
% table_out(6:8,6) = {[0,1]};
% table_out(9:size(lm.PredictorNames(5:end),1)+7,6) = lm.VariableInfo{lm.PredictorNames(6:9),2};
% table_out(2:size(lm.PredictorNames(1:3),1)+2,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(1:4)})');
% table_out(6,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='6')}; % Respondent felt pressured to vote for the program
% table_out(7,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='7')}; % Respondent felt pressured to vote against the program
% table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='8')}; % Respondent could not respond if felt free of pressured to vote for or against the program
% % table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='9')}; % Respondent could not respond if felt free of pressured to vote for or against the program
% table_out(9:size(lm.PredictorNames(5:end),1)+7,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(6:end)})');
% table_out(end+1,1) = {'R2 (adj)'};
% table_out(end,2) = num2cell(lm.Rsquared.Adjusted);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);

% survey quality controls - binary probit:
lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.Incorrect_pause_q, DummyVar(tbl.Pressure_to_vote,1), tbl.Involevent_c, tbl.Understanding_c, tbl.Sit_stand_c, tbl.Intercept],tbl.Vote_No,'linear','distr','binomial','link','probit') % bid + income + quality

% this is used for exporting the results to Excel:
table_out = lm.CoefficientNames';
table_out(:,2:5) = table2cell(lm.Coefficients); 
table_out(2:size(lm.PredictorNames(1:3),1)+2,6) = lm.VariableInfo{lm.PredictorNames(1:4),2};
table_out(6:8,6) = {[0,1]};
table_out(9:12,6) = lm.VariableInfo{lm.PredictorNames(6:9),2};
table_out(2:size(lm.PredictorNames(1:3),1)+2,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(1:4)})');
table_out(6,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)})}; % Respondent felt pressured to vote for the program
table_out(7,7) = {nanmean(lm.Variables{:,lm.PredictorNames(6)})}; % Respondent felt pressured to vote against the program
table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(7)})}; % Respondent could not respond if felt free of pressured to vote for or against the program
% table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='9')}; % Respondent could not respond if felt free of pressured to vote for or against the program
table_out(9:12,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(8:end)})');
table_out(end+1,1) = {'LL'};
table_out(end,2) = num2cell(lm.LogLikelihood);
table_out(end+1,1) = {'AIC/n'};
table_out(end,2) = num2cell((2*lm.NumCoefficients-2*lm.LogLikelihood)./lm.NumObservations);
table_out(end+1,1) = {'k (parameters)'};
table_out(end,2) = num2cell(lm.NumCoefficients);
table_out(end+1,1) = {'n (observations)'};
table_out(end,2) = num2cell(lm.NumObservations);



clear table_out lm

% sum(DATA.D13==5) ./ numel(DATA.D13) % free to vote
% sum(DATA.D13==6)
% sum(DATA.D13==7)
% sum(DATA.D13==8)
% sum(DATA.D13==9)


%% reasons for voting 'no'

% DATA.Q28(isnan(DATA.Q28) & (DATA.Q27 == 2)) = 10;

no_reasons = unique(DATA.Q28(DATA.Q27 == 2));
Tab_reasons_for_no = {};
for i = 1:size(no_reasons)
    Tab_reasons_for_no(i,1:2) = {i,sum(DATA.Q28(DATA.Q27 == 2)==i)};
end
Tab_reasons_for_no(:,3) = num2cell([Tab_reasons_for_no{:,2}]./sum([Tab_reasons_for_no{:,2}]))';
Tab_reasons_for_no(1) = {'I have no income to pay this amount'};
Tab_reasons_for_no(2) = {'I`d rather use this money for another purpose'};
Tab_reasons_for_no(3) = {'It is not important to stop the mud dams'};
Tab_reasons_for_no(4) = {'I do not want to give my money to the miners'};
Tab_reasons_for_no(5) = {'The money from this tax will be mismanaged'};
Tab_reasons_for_no(6) = {'The money from this tax will not be used to deploy dry tailings'};
Tab_reasons_for_no(7) = {'The money goes to corruption'};
Tab_reasons_for_no(8) = {'I already paid a lot of tax'};
Tab_reasons_for_no(9) = {'Other reason'};
Tab_reasons_for_no(10) = {'Refuse to answer'};
Tab_reasons_for_no(11) = {'The value is too high for me'};
Tab_reasons_for_no(12) = {'The government should pay, not the population'};
Tab_reasons_for_no(13) = {'The government and the miners should pay, not the population'};
Tab_reasons_for_no(14) = {'Money should be used for another purpose'};
Tab_reasons_for_no(15) = {'Concerned about other payers'};
Tab_reasons_for_no(16,1) = {'Total'};
Tab_reasons_for_no(16,2) = {sum([Tab_reasons_for_no{:,2}])};
Tab_reasons_for_no(16,3) = {1};
Tab_reasons_for_no = [{'Reasons','Cases','Share'}; Tab_reasons_for_no];

clear i no_reasons


%% regressions - explanatory variables of 'protest' votes


% socio-demographics - simple linear regression:
% lm = fitlm(tbl,'Protest_no~Log_Bid+Log_Income_filled+Income_missing+log_HH_wealth+Age+Age_2+Female+HH_size_c+Education+Work_status') % bid + income + socio-demographics + education + work status

% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% [~,SE,coef] = hac(lm,'type','HC','weights','HC1','display','off'); % robust s.e.
% table_out(:,3) = num2cell(SE); % substituting for robust s.e.
% table_out(:,4) = num2cell(cell2mat(table_out(:,2))./cell2mat(table_out(:,3)));
% table_out(:,5) = num2cell(pv(cell2mat(table_out(:,2)),cell2mat(table_out(:,3))));
% table_out(2:3,6) = lm.VariableInfo{lm.PredictorNames(1:2),2};
% table_out(4:13,6) = {[0,1]};
% table_out(14:18,6) = lm.VariableInfo{lm.PredictorNames(5:9),2};
% table_out(19:end,6) = {[0,1]};
% table_out(2:4,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(1:3)})');
% table_out(5,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='3')};
% table_out(6,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='4')};
% table_out(7,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='5')};
% table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='6')};
% table_out(9,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='7')};
% table_out(10,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='8')};
% table_out(11,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='9')};
% table_out(12,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='10')};
% table_out(13,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)}=='11')};
% table_out(14:18,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(5:9)})');
% table_out(19,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='2')};
% table_out(20,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='3')};
% table_out(21,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='4')};
% table_out(22,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='5')};
% table_out(23,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='6')};
% table_out(24,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)}=='7')};
% table_out(end+1,1) = {'R2 (adj)'};
% table_out(end,2) = num2cell(lm.Rsquared.Adjusted);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);

% socio-demographics - binary probit:
% lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, DummyVar(tbl.Work_status,1), tbl.HH_size_c, tbl.Female, tbl.Age, tbl.Age_2, tbl.log_HH_wealth, DummyVar(tbl.Education,1) ], tbl.Protest_no,'linear','distr','binomial','link','probit') % bid + income + socio-demographics + education + work status

% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% table_out(2:3,6) = lm.VariableInfo{lm.PredictorNames(1:2),2};
% table_out(4:13,6) = {[0,1]};
% table_out(14:18,6) = lm.VariableInfo{lm.PredictorNames(14:18),2};
% table_out(19:end,6) = {[0,1]};
% table_out(2:4,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(1:3)})');
% table_out(5,7) = {nanmean(lm.Variables{:,lm.PredictorNames(4)})};
% table_out(6,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)})};
% table_out(7,7) = {nanmean(lm.Variables{:,lm.PredictorNames(6)})};
% table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(7)})};
% table_out(9,7) = {nanmean(lm.Variables{:,lm.PredictorNames(8)})};
% table_out(10,7) = {nanmean(lm.Variables{:,lm.PredictorNames(9)})};
% table_out(11,7) = {nanmean(lm.Variables{:,lm.PredictorNames(10)})};
% table_out(12,7) = {nanmean(lm.Variables{:,lm.PredictorNames(11)})};
% table_out(13,7) = {nanmean(lm.Variables{:,lm.PredictorNames(12)})};
% table_out(14:18,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(13:17)})');
% table_out(19,7) = {nanmean(lm.Variables{:,lm.PredictorNames(18)})};
% table_out(20,7) = {nanmean(lm.Variables{:,lm.PredictorNames(19)})};
% table_out(21,7) = {nanmean(lm.Variables{:,lm.PredictorNames(20)})};
% table_out(22,7) = {nanmean(lm.Variables{:,lm.PredictorNames(21)})};
% table_out(23,7) = {nanmean(lm.Variables{:,lm.PredictorNames(22)})};
% table_out(24,7) = {nanmean(lm.Variables{:,lm.PredictorNames(23)})};
% table_out(end+1,1) = {'LL'};
% table_out(end,2) = num2cell(lm.LogLikelihood);
% table_out(end+1,1) = {'AIC/n'};
% table_out(end,2) = num2cell((2*lm.NumCoefficients-2*lm.LogLikelihood)./lm.NumObservations);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);

% debriefing questions - simple linear regression:
% lm = fitlm(tbl,'Protest_no~Log_Bid+Log_Income_filled+Income_missing+Visited_Mariana_yes+Concerned_environment_cf+Trust_damage_assessment_cf+Believe_recovery_time_cf+Believe_DT_solution_cf+Believe_DT_time_cf+Believe_DT_vote_cf+Believe_tax_rise_cf+Believe_DT_companies_cf+Believe_tax_amount_cf+Payment_difficult_cf + Concerned_environment_cf_missing+Trust_damage_assessment_cf_missing+Believe_recovery_time_cf_missing+Believe_DT_solution_cf_missing+Believe_DT_time_cf_missing+Believe_DT_vote_cf_missing+Believe_tax_rise_cf_missing+Believe_DT_companies_cf_missing+Believe_tax_amount_cf_missing+Payment_difficult_cf_missing') % bid + income + debriefing

% this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% [~,SE,coef] = hac(lm,'type','HC','weights','HC1','display','off'); % robust s.e.
% table_out(:,3) = num2cell(SE); % substituting for robust s.e.
% table_out(:,4) = num2cell(cell2mat(table_out(:,2))./cell2mat(table_out(:,3)));
% table_out(:,5) = num2cell(pv(cell2mat(table_out(:,2)),cell2mat(table_out(:,3))));
% table_out(2:25,6) = lm.VariableInfo{lm.PredictorNames,2};
% table_out(2:25,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames})');
% table_out(end+1,1) = {'R2 (adj)'};
% table_out(end,2) = num2cell(lm.Rsquared.Adjusted);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);

% debriefing questions - binary probit:
% lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.Visited_Mariana_yes, tbl.Concerned_environment_cf, tbl.Trust_damage_assessment_cf, tbl.Believe_recovery_time_cf, tbl.Believe_DT_solution_cf, tbl.Believe_DT_time_cf, tbl.Believe_DT_vote_cf, tbl.Believe_tax_rise_cf, tbl.Believe_DT_companies_cf, tbl.Believe_tax_amount_cf, tbl.Payment_difficult_cf , tbl.Concerned_environment_cf_missing, tbl.Trust_damage_assessment_cf_missing, tbl.Believe_recovery_time_cf_missing, tbl.Believe_DT_solution_cf_missing, tbl.Believe_DT_time_cf_missing, tbl.Believe_DT_vote_cf_missing, tbl.Believe_tax_rise_cf_missing, tbl.Believe_DT_companies_cf_missing, tbl.Believe_tax_amount_cf_missing, tbl.Payment_difficult_cf_missing ], tbl.Protest_no,'linear','distr','binomial','link','probit') % bid + income + debriefing

% this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% table_out(2:25,6) = lm.VariableInfo{lm.PredictorNames,2};
% table_out(2:25,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames})');
% table_out(end+1,1) = {'LL'};
% table_out(end,2) = num2cell(lm.LogLikelihood);
% table_out(end+1,1) = {'AIC/n'};
% table_out(end,2) = num2cell((2*lm.NumCoefficients-2*lm.LogLikelihood)./lm.NumObservations);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);


% survey quality controls - simple linear regression:
% lm = fitlm(tbl,'Protest_no~Log_Bid+Log_Income_filled+Income_missing+Incorrect_pause_q+Pressure_to_vote+Involevent_c+Understanding_c+Sit_stand_c+Intercept') % bid + income + quality

% % this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% [~,SE,coef] = hac(lm,'type','HC','weights','HC1','display','off'); % robust s.e.
% table_out(:,3) = num2cell(SE); % substituting for robust s.e.
% table_out(:,4) = num2cell(cell2mat(table_out(:,2))./cell2mat(table_out(:,3)));
% table_out(:,5) = num2cell(pv(cell2mat(table_out(:,2)),cell2mat(table_out(:,3))));
% table_out(2:size(lm.PredictorNames(1:3),1)+2,6) = lm.VariableInfo{lm.PredictorNames(1:4),2};
% table_out(6:8,6) = {[0,1]};
% table_out(9:size(lm.PredictorNames(5:end),1)+7,6) = lm.VariableInfo{lm.PredictorNames(6:9),2};
% table_out(2:size(lm.PredictorNames(1:3),1)+2,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(1:4)})');
% table_out(6,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='6')}; % Respondent felt pressured to vote for the program
% table_out(7,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='7')}; % Respondent felt pressured to vote against the program
% table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='8')}; % Respondent could not respond if felt free of pressured to vote for or against the program
% % table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='9')}; % Respondent could not respond if felt free of pressured to vote for or against the program
% table_out(9:size(lm.PredictorNames(5:end),1)+7,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(6:end)})');
% table_out(end+1,1) = {'R2 (adj)'};
% table_out(end,2) = num2cell(lm.Rsquared.Adjusted);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);

% survey quality controls - binary probit:
% lm = fitglm([tbl.Log_Bid, tbl.Log_Income_filled, tbl.Income_missing, tbl.Incorrect_pause_q, DummyVar(tbl.Pressure_to_vote,1), tbl.Involevent_c, tbl.Understanding_c, tbl.Sit_stand_c, tbl.Intercept], tbl.Protest_no, 'linear','distr','binomial','link','probit') % bid + income + quality

% this is used for exporting the results to Excel:
% table_out = lm.CoefficientNames';
% table_out(:,2:5) = table2cell(lm.Coefficients); 
% table_out(2:size(lm.PredictorNames(1:3),1)+2,6) = lm.VariableInfo{lm.PredictorNames(1:4),2};
% table_out(6:8,6) = {[0,1]};
% table_out(9:12,6) = lm.VariableInfo{lm.PredictorNames(6:9),2};
% table_out(2:size(lm.PredictorNames(1:3),1)+2,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(1:4)})');
% table_out(6,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)})}; % Respondent felt pressured to vote for the program
% table_out(7,7) = {nanmean(lm.Variables{:,lm.PredictorNames(6)})}; % Respondent felt pressured to vote against the program
% table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(7)})}; % Respondent could not respond if felt free of pressured to vote for or against the program
% % table_out(8,7) = {nanmean(lm.Variables{:,lm.PredictorNames(5)}=='9')}; % Respondent could not respond if felt free of pressured to vote for or against the program
% table_out(9:12,7) = num2cell(nanmean(lm.Variables{:,lm.PredictorNames(8:end)})');
% table_out(end+1,1) = {'LL'};
% table_out(end,2) = num2cell(lm.LogLikelihood);
% table_out(end+1,1) = {'AIC/n'};
% table_out(end,2) = num2cell((2*lm.NumCoefficients-2*lm.LogLikelihood)./lm.NumObservations);
% table_out(end+1,1) = {'k (parameters)'};
% table_out(end,2) = num2cell(lm.NumCoefficients);
% table_out(end+1,1) = {'n (observations)'};
% table_out(end,2) = num2cell(lm.NumObservations);


clear table_out lm tbl tbl_no coef SE


%% drop protest 'no' votes (Q28  = 4, 5, 6, 7 (but not 8)).


filter = DATA.protest; % | (DATA.Q28 == 8);
fields = fieldnames(DATA);
for i = 1:numel(fields)
    tmp = DATA.(fields{i});
    DATA.(fields{i}) = tmp(~filter,:);
end
clear fields tmp filter i


%% non-parametric analysis (without protest responses)


bids = unique(DATA.bid);

% Frequency table with weighting:
Frequency_table_np_W = zeros(length(bids),6);
Frequency_table_np_W(:,1) = bids;
for i = 1:length(bids)
    Frequency_table_np_W(i,2) = sum(DATA.WeightwoProtest_Imputed(DATA.bid == bids(i)).*(DATA.Q27(DATA.bid == bids(i)) == 2)); % no of people who voted no (weighted)
    Frequency_table_np_W(i,3) = sum(DATA.WeightwoProtest_Imputed(DATA.bid == bids(i)).*(DATA.Q27(DATA.bid == bids(i)) == 1)); % no of people who voted yes (weighted)
    Frequency_table_np_W(i,4) = sum(DATA.WeightwoProtest_Imputed(DATA.bid == bids(i))); % no of people total (weighted)
end
Frequency_table_np_W(:,5) = Frequency_table_np_W(:,2)./Frequency_table_np_W(:,4);  % NO answers
Frequency_table_np_W(:,6) = Frequency_table_np_W(:,3)./Frequency_table_np_W(:,4);

% Frequency table without weighting
Frequency_table_np = zeros(length(bids),6);
Frequency_table_np(:,1) = bids;
for i = 1:length(bids)
    Frequency_table_np(i,2) = sum(DATA.Q27(DATA.bid == bids(i)) == 2); % no of people who voted no (weighted)
    Frequency_table_np(i,3) = sum(DATA.Q27(DATA.bid == bids(i)) == 1); % no of people who voted yes (weighted)
    Frequency_table_np(i,4) = sum(DATA.bid == bids(i)); % no of people total (weighted)
end
Frequency_table_np(:,5) = Frequency_table_np(:,2)./Frequency_table_np(:,4); % NO answers
Frequency_table_np(:,6) = Frequency_table_np(:,3)./Frequency_table_np(:,4);

% Scaling, so that the total number of individuals would not change
Frequency_table_np_W(:,2:4) = Frequency_table_np_W(:,2:4).*(Frequency_table_np(:,4)./Frequency_table_np_W(:,4)); 

% Lewbel_Watanabe WTP (weigted):
WTP = sum((Frequency_table_np_W(:,1)-[0;Frequency_table_np_W(1:end-1,1)]).*Frequency_table_np_W(:,3)./Frequency_table_np_W(:,4)); % mean WTP
SD = sqrt(sum(Frequency_table_np_W(:,5).*(1-Frequency_table_np_W(:,5))./Frequency_table_np_W(:,4).*((Frequency_table_np_W(:,1)-[0;Frequency_table_np_W(1:end-1,1)])).^2)); %. s.e. (based on Haab McConnell) 

Results_nonparametric_np = {'WTP (mean)','WTP (s.e.)'};
Results_nonparametric_np(2,:) = num2cell([WTP,SD])

% plot LW CDF
figure(4)
SEA = sqrt(Frequency_table_np_W(:,2).*Frequency_table_np_W(:,3)./(Frequency_table_np_W(:,4).^3)); % standard errors based on ML Hessian
xx = linspace(0,200,500);
hold on;
KMplot(1) = stairs([0;Frequency_table_np_W(:,1)],[0;Frequency_table_np_W(:,5)],'b-'); % Taking NO answers
KMplot(2) = stairs([0;Frequency_table_np_W(:,1)],[0;Frequency_table_np_W(:,5)+norminv(0.025)*SEA],'r--');
KMplot(3) = stairs([0;Frequency_table_np_W(:,1)],[0;Frequency_table_np_W(:,5)+norminv(0.975)*SEA],'r--');
set(KMplot(1),'linewidth',2);
hold off
xlabel('WTP'); ylabel('Probability'); title('Empirical CDF')
set(gca, 'YGrid', 'on', 'GridLineStyle', ':')
ylim([0,1])
set(gca,'XTick', Frequency_table_np_W(:,1))
set(gca,'Position',[.13 .11 .85 .82]);
set(gcf,'Color', 'w')
legend([KMplot(1),KMplot(2)],'Lewbel-Watanabe (lower bound) estimator','95% confidence interval','Location', 'southeast')

saveas(gcf,'LW CDF np','png')

clear xx WTPA SEA bids KMplot 


clear WTP SD i 


%% parametric analysis:


% create lower and upper bound for each respondent
INPUT.bounds = DATA.bounds;
INPUT.WT = DATA.WeightwoProtest_Imputed;

INPUT.Results = [];

% try 
%     
% % fit parametric distributions to data:
% INPUT.Spike = 0; % no zero inflation
% load('Results_parametric0_np');
% INPUT.Results = Results_parametric0;
% % INPUT.Results = [];
% [Results_parametric0, Results_parametric_summary0] = FitParametricDistributions(INPUT);
% save('Results_parametric0i_np.mat','Results_parametric0')
% save('Results_parametric_summary0i_np.mat','Results_parametric_summary0')
% 
% INPUT.Spike = 1; % with zero inflation
% load('Results_parametric1_np');
% INPUT.Results = Results_parametric1;
% % INPUT.Results = [];
% [Results_parametric1, Results_parametric_summary1] = FitParametricDistributions(INPUT);
% save('Results_parametric1i_np.mat','Results_parametric1')
% save('Results_parametric_summary1i_np.mat','Results_parametric_summary1')
% 
% sendmail('mik@czaj.org','MATLAB: D1 - done!');
%     
% catch theErrorInfo
%     
% sendmail('mik@czaj.org','MATLAB: D1 - error!');
% rethrow(theErrorInfo)
% 
% end
% 
% % retain the best starting values from two sets of estimats:
% R1 = load('Results_parametric0_np.mat');
% R2 = load('Results_parametric0sqp_np.mat');
%     for i=1:length(R1.Results_parametric0.Distributions)
%         if ((R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).fval < R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).fval) && (R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).RealMin == 0)) || ...
%                 ((R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).RealMin == 0) && (R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).RealMin == 1))                
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).fval - R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).fval
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).beta = R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).beta;
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).fval = R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).fval;
%             R1.Results_parametric0.(R1.Results_parametric0.Distributions{i,2}).RealMin = R2.Results_parametric0.(R2.Results_parametric0.Distributions{i,2}).RealMin;
%         end
%     end  
% save('Results_parametric0_np.mat','-struct','R1') %- this is my newest results file
%   
% R1 = load('Results_parametric1_np.mat');
% R2 = load('Results_parametric1sqp_np.mat');
%     for i=1:length(R1.Results_parametric1.Distributions)
%         if ((R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).fval < R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).fval) && (R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).RealMin == 0)) || ...
%                 ((R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).RealMin == 0) && (R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).RealMin == 1))                
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).fval - R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).fval
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).beta = R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).beta;
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).fval = R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).fval;
%             R1.Results_parametric1.(R1.Results_parametric1.Distributions{i,2}).RealMin = R2.Results_parametric1.(R2.Results_parametric1.Distributions{i,2}).RealMin;
%         end
%     end    
% save('Results_parametric1_np','-struct','R1') %- this is my newest results file



% compile the results of the parametric analysis:
load('Results_parametric0_np');
load('Results_parametric1_np');
load('Results_parametric_summary0_np');
load('Results_parametric_summary1_np');
Results_parametric_np(1:size(Results_parametric0.Distributions,1)+size(Results_parametric1.Distributions,1),1) = [Results_parametric0.Distributions(:,2);Results_parametric1.Distributions(:,2)];
Results_parametric_summary0 = [Results_parametric_summary0(:,1),zeros(size(Results_parametric_summary0(:,1))),Results_parametric_summary0(:,2:end)];
Results_parametric_summary1 = [Results_parametric_summary1(:,1),ones(size(Results_parametric_summary1(:,1))),Results_parametric_summary1(:,2:end)];
Results_parametric_np(1:size(Results_parametric0.Distributions,1),2:size(Results_parametric_summary0,2)+1) = num2cell(Results_parametric_summary0);
Results_parametric_np(size(Results_parametric1.Distributions,1)+1:end,2:size(Results_parametric_summary1,2)+1) = num2cell(Results_parametric_summary1);
% drop distributions that did not converge:
for i = 1:size(Results_parametric_np,1)
    idx(i,1) = (Results_parametric_np{i,end-1} > 100) | (Results_parametric_np{i,end-1} == 0) | isnan(Results_parametric_np{i,end-1}) | isinf(Results_parametric_np{i,end-1}) | ~isreal(Results_parametric_np{i,end-1}) | ...
    (Results_parametric_np{i,end-2} > 500) | (Results_parametric_np{i,end-2} == 0) | isnan(Results_parametric_np{i,end-2}) | isinf(Results_parametric_np{i,end-2}) | ~isreal(Results_parametric_np{i,end-2});
end
Results_parametric_np(idx==1,:) = [];
Results_parametric_np = sortrows(Results_parametric_np,[5,4]);
Results_parametric_np = [{'Distribution','Log-likelihood','Zero inflation','AIC/n','BIC/n','n - observations','k - parameters','WTP (mean)','WTP (s.e.)','RealMin'};Results_parametric_np];

Results_parametric_np


% plot step-curve with CDF of the best fitting parametric dist.
figure(5)
[WTPA_np,freq_tableA_np] = KaplanMeierEstimator(DATA.bid,DATA.Q27==1);
% SEA = sqrt(freq_tableA(:,2).*freq_tableA(:,3)./(freq_tableA(:,4).^3)); % standard errors based on ML Hessian
SEA = sqrt(Frequency_table_np_W(:,2).*Frequency_table_np_W(:,3)./(Frequency_table_np_W(:,4).^3)); % weighted version
xx = linspace(0,max(DATA.bid),500);
% Betas_param = Results_parametric0.Negative_Binomial.beta';
% wblF = cdf('NegativeBinomial',xx,Betas_param(1),Betas_param(2));

% Betas_param = Results_parametric1.Exponential.beta';
% pSpike = normcdf(Betas_param(2)); % p1
% wblF = pSpike + (1-pSpike).*cdf('Exponential',xx,Betas_param(1));

Betas_param = Results_parametric1.Gamma.beta';
pSpike = normcdf(Betas_param(3)); % p1
wblF = pSpike + (1-pSpike).*cdf('Gamma',xx,Betas_param(1),Betas_param(2));

sim1 = 1e5;
% Betas_param_sim = mvnrnd(Betas_param,Results_parametric0.Negative_Binomial.ihess,sim1)';
% Betas_param_sim = mvnrnd(Betas_param,Results_parametric1.Exponential.ihess,sim1)';
Betas_param_sim = mvnrnd(Betas_param,Results_parametric1.Gamma.ihess,sim1)';
wblF_sim = zeros(sim1,500);
parfor i = 1:sim1
%     wblF_sim(i,:) = cdf('NegativeBinomial',xx,Betas_param_sim(1,i),Betas_param_sim(2,i));
%     pSpike = normcdf(Betas_param_sim(2,i)); % p1
%     wblF_sim(i,:) = pSpike + (1-pSpike).*cdf('Exponential',xx,Betas_param_sim(1,i));    
    pSpike = normcdf(Betas_param_sim(3,i)); % p1
    wblF_sim(i,:) = pSpike + (1-pSpike).*cdf('Gamma',xx,Betas_param_sim(1,i),Betas_param_sim(2,i));  
end
wblF_sim_l = quantile(wblF_sim,0.025);
wblF_sim_u = quantile(wblF_sim,0.975);
hold on;
% KMplot(1) = stairs([0;freq_tableA(:,1)],[0;freq_tableA(:,6)],'b-');
% KMplot(2) = stairs([0;freq_tableA(:,1)],[0;freq_tableA(:,6)+norminv(0.025)*SEA],'b--');
% KMplot(3) = stairs([0;freq_tableA(:,1)],[0;freq_tableA(:,6)+norminv(0.975)*SEA],'b--');
KMplot(1) = stairs([0;Frequency_table_np_W(:,1)],[0;Frequency_table_np_W(:,5)],'b-'); % Taking NO answers
KMplot(2) = stairs([0;Frequency_table_np_W(:,1)],[0;Frequency_table_np_W(:,5)+norminv(0.025)*SEA],'b--');
KMplot(3) = stairs([0;Frequency_table_np_W(:,1)],[0;Frequency_table_np_W(:,5)+norminv(0.975)*SEA],'b--');
DISTplot(1) = plot(xx,wblF,'r-');
DISTplot(2) = plot(xx,wblF_sim_l,'r--');
DISTplot(3) = plot(xx,wblF_sim_u,'r--');
set(KMplot(1),'linewidth',2);
set(DISTplot(1),'linewidth',2);
hold off
xlabel('WTP'); ylabel('Probability'); title('Empirical CDF')
set(gca, 'YGrid', 'on', 'GridLineStyle', ':')
ylim([0,1])
% set(gca,'XTick', freq_tableA(:,1))
set(gca,'XTick', Frequency_table_np_W(:,1))
set(gca,'Position',[.13 .11 .85 .82]);
set(gcf,'Color', 'w')
legend([KMplot(1),KMplot(2), DISTplot(1),DISTplot(2)],'Lewbel-Watanabe (lower bound)','95% confidence interval','Fitted gamma distribution','95% confidence interval', 'Location', 'southeast')

saveas(gcf,'LW + param CDF no protest','png')

clear Distributions i idx INPUT Results_summary_0 Results_summary_1 
clear Betas_param Betas_param_sim DISTplot freq_tableA i idx INPUT KMplot Results_parametric0 Results_parametric1 Results_parametric_summary0 Results_parametric_summary1
clear SEA sim1 wblF wblF_sim wblF_sim_l wblF_sim_u xx WTPA 
